summaryrefslogtreecommitdiffstats
path: root/src/sources/labelsourcePrefs.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/sources/labelsourcePrefs.cpp')
-rw-r--r--src/sources/labelsourcePrefs.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/sources/labelsourcePrefs.cpp b/src/sources/labelsourcePrefs.cpp
index 4ff75fc..db9b675 100644
--- a/src/sources/labelsourcePrefs.cpp
+++ b/src/sources/labelsourcePrefs.cpp
@@ -23,11 +23,11 @@
#include <tqwhatsthis.h>
/*
* Constructs a LabelSourcePrefs as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
-LabelSourcePrefs::LabelSourcePrefs( TQWidget* tqparent, const char* name, WFlags fl )
- : TQWidget( tqparent, name, fl )
+LabelSourcePrefs::LabelSourcePrefs( TQWidget* parent, const char* name, WFlags fl )
+ : TQWidget( parent, name, fl )
{
if ( !name )
setName( "LabelSourcePrefs" );
@@ -23,11 +23,11 @@
#include <tqwhatsthis.h>
/*
- * Constructs a LabelSourcePrefs as a child of 'tqparent', with the
+ * Constructs a LabelSourcePrefs as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/